%define anolis_release 1

Name:		libical
Summary:	An implementation of iCalendar protocols and data formats
Version:	3.0.18
Release:	%{anolis_release}%{?dist}
License:	LGPL-2.1-only or MPLv2.0
URL:		https://libical.github.io/libical/
Source:		https://github.com/%{name}/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:	gcc gcc-c++ cmake make
BuildRequires:	pkgconfig pkgconfig(gobject-2.0) pkgconfig(gobject-introspection-1.0) pkgconfig(libxml-2.0) pkgconfig(icu-i18n) pkgconfig(icu-uc)
BuildRequires:	perl(Getopt::Std) perl(lib)
BuildRequires:	python3 vala python3-pip python3-gobject
BuildRequires:	gtk-doc

Requires:	tzdata

%description
Libical is an Open Source implementation of the iCalendar protocols
and protocol data units. The iCalendar specification describes how
calendar clients can communicate with calendar servers so users can
store their calendar data and arrange meetings with other users.

Libical implements RFC5545, RFC5546, RFC7529;
the CalDav scheduling extensions in RFC6638;
iCalendar extensions in RFC7986;
plus the iCalendar iMIP protocol in RFC6047.

%package devel
Summary:	Development files for %{name}
Requires:	%{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for developing
applications that use %{name}.

%package doc
Summary:	Documentation files for %{name}
Requires:	%{name} = %{version}-%{release}
BuildArch:	noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package glib
Summary:	GObject wrapper for %{name} library
Requires:	%{name} = %{version}-%{release}

%description glib
This package provides a GObject wrapper for %{name} library with support
of GObject Introspection.

%package glib-devel
Summary:	Development files for building against %{name}-glib
Requires:	%{name}-devel = %{version}-%{release}
Requires:	%{name}-glib = %{version}-%{release}

%description glib-devel
Development files needed for building things which link against %{name}-glib.

%package glib-doc
Summary:	Documentation files for %{name}-glib
BuildArch:	noarch

%description glib-doc
This package contains developer documentation for %{name}-glib.

%prep
%autosetup -n %{name}-%{version} -p1

%build
%{cmake} \
  -DUSE_INTEROPERABLE_VTIMEZONES=true \
  -DICAL_ALLOW_EMPTY_PROPERTIES=true \
  -DGOBJECT_INTROSPECTION=true \
  -DICAL_GLIB=true \
  -DICAL_GLIB_VAPI=true \
  -DSHARED_ONLY=true

%cmake_build -j1

%install
%cmake_install

rm %{buildroot}/%{_libexecdir}/libical/ical-glib-src-generator

%generate_compatibility_deps

%check
make test ARGS="-V" -C %{_vpath_builddir}

%files
%dir %{abidir}
%license LICENSE
%{_libdir}/libical.so.3
%{_libdir}/libical.so.%{version}
%{abidir}/libical.dump
%{_libdir}/libical_cxx.so.3
%{_libdir}/libical_cxx.so.%{version}
%{abidir}/libical_cxx.dump
%{_libdir}/libicalss.so.3
%{_libdir}/libicalss.so.%{version}
%{abidir}/libicalss.dump
%{_libdir}/libicalss_cxx.so.3
%{_libdir}/libicalss_cxx.so.%{version}
%{abidir}/libicalss_cxx.dump
%{_libdir}/libicalvcal.so.3
%{_libdir}/libicalvcal.so.%{version}
%{abidir}/libicalvcal.dump
%{_libdir}/girepository-1.0/ICal-3.0.typelib
%{_datadir}/gir-1.0/ICal-3.0.gir

%files devel
%{_libdir}/libical.so
%{_libdir}/libical_cxx.so
%{_libdir}/libicalss.so
%{_libdir}/libicalss_cxx.so
%{_libdir}/libicalvcal.so
%{_libdir}/pkgconfig/libical.pc
%{_libdir}/cmake/LibIcal/
%{_includedir}/libical/

%files doc
%doc README.md ReleaseNotes.txt THANKS doc/UsingLibical.md

%files glib
%{_libdir}/libical-glib.so.3
%{_libdir}/libical-glib.so.%{version}
%{abidir}/libical-glib.dump
%{_libdir}/girepository-1.0/ICalGLib-3.0.typelib
%{_datadir}/gir-1.0/ICalGLib-3.0.gir

%files glib-devel
%{_libdir}/libical-glib.so
%{_libdir}/pkgconfig/libical-glib.pc
%{_includedir}/libical-glib/
%{_datadir}/vala/vapi/libical-glib.vapi

%files glib-doc
%{_datadir}/gtk-doc/html/%{name}-glib

%changelog
* Mon Feb 17 2025 mgb01105731 <mgb01105731@alibaba-inc.com> - 3.0.18-1
- Update to 3.0.18 from 3.0.16
- Update License tag to SPDX

* Sat Apr 08 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 3.0.16-2
- Optimize the spec file

* Sat Mar 04 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 3.0.16-1
- update to 3.0.16

* Mon Dec 05 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.0.14-2
- rebuild for icu update

* Thu Jun 9 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 3.0.14-1
- init from upstream
